@@ -573,7 +573,7 @@ class ApiGroupV4(object):
         self.apis.append(api)
 
 class ApiModelV4(object):
-    def __init__(self, root, preifx, version, groups, apiServer='', srvVersion='', title='', description=''):
+    def __init__(self, root, preifx, version, groups, apiServer='', srvVersion='', title='', description='', authmap={}):
         self.root = root
         self.prefix = preifx
         self.version = version
@@ -583,6 +583,8 @@ class ApiModelV4(object):
         self.description = description
         self.apiServer = apiServer
         self.srvVersion = srvVersion
+        self.authmap = authmap
+        self.resp = {'fields': ['data', 'msg', 'stat'], 'in': 'data'}
 
     def __repr__(self):
         txt = 'root %s %s\n' % (self.prefix, self.version)
@@ -712,7 +714,6 @@ class ApiModelV4(object):
         VERSION = 'v1'
         lineno = 1
         root = lines[0].strip()
-        print(root, type(root), root[0], type(root[0]))
         assert_error(is_valid_var(root[0]), '开头必须是有效字母', lineno, root)
         items = root.split(' ')
         assert_error(len(items) >= 2, '无效的apimodel', lineno, root)
@@ -737,6 +738,8 @@ class ApiModelV4(object):
         description = ''
         apiServer = ''
         srvVersion = ''
+        authmap = {}
+        jsonResp = {'fields': ['data', 'msg', 'stat'], 'in': 'data'}
 
         for line in lines[1:]:
             lineno += 1
@@ -746,18 +749,33 @@ class ApiModelV4(object):
 
             # config
             if line.startswith('- title:'):
-                title = line.lstrip('- title:').strip()
+                title = line.replace('- title:', '').strip()
                 continue
             if line.startswith('- description:'):
-                description = line.lstrip('- description:').strip()
+                description = line.replace('- description:', '').strip()
                 continue
             if line.startswith('- apiserver:'):
-                apiServer = line.lstrip('- apiserver:').strip()
+                apiServer = line.replace('- apiserver:', '').strip()
                 continue
             if line.startswith('- version:'):
-                srvVersion = line.lstrip('- version:').strip()
+                srvVersion = line.replace('- version:', '').strip()
                 continue
-            
+            if line.startswith('- authmap:'):
+                line = line.replace('- authmap:', '').strip()
+                for item in line.split(','):
+                    kv = item.split('=')
+                    authmap[kv[0].strip()] = kv[1].strip()
+                continue
+            if line.startswith('- resp:'):
+                line = line.replace('- resp:', '').strip()
+                for item in line.split(' '):
+                    kv = item.split('=')
+                    if kv[0] == 'fields':
+                        jsonResp['fields'] = kv[1].split(',')
+                    if kv[0] == 'in':
+                        jsonResp['in'] = kv[1].strip()
+                continue
+             
             width = len(line) - len(line.lstrip())
             assert_error(width % TAB_WIDTH == 0, '宽带不是%s的倍数' % TAB_WIDTH, lineno, line)
             deep = int(width / TAB_WIDTH)
@@ -834,7 +852,9 @@ class ApiModelV4(object):
                             currentNestParam.append(param)
                     nestParam.addChildren(param)
 
-        return cls(root, PREFIX, VERSION, groups, apiServer, srvVersion, description)
+        _cls = cls(root, PREFIX, VERSION, groups, apiServer, srvVersion, title, description, authmap)
+        _cls.resp = jsonResp
+        return _cls
 
 class GoFuncV4(object):
     def __init__(self, name):
