@@ -8,6 +8,7 @@ import sys
 import json
 import time
 
+from .helper import is_macos
 from .conf import *
 if M2C_VERSION == 'v3':
     from .m2c import goswagger3 as goswagger
@@ -214,3 +215,15 @@ def debug():
 def vendor():
     os.chdir(GOPHER_DIR)
     os.system('go mod vendor')
+
+def swaggerCodegen(lang, outputDir, pkg=''):
+    if os.system('which swagger-codegen') != 0:
+        print(Color.red('swagger-codgen 不存在, 安装参考: https://github.com/swagger-api/swagger-codegen'))
+        if is_macos():
+            print(Color.green('当前为macos 自动执行安装中...'))
+            _run('brew install swagger-codegen')
+        return
+    if pkg == '':
+        _run('swagger-codegen generate -i %s -l %s -o %s' % (SWAGGER_YAML_PATH, lang, outputDir))
+    else:
+        _run('swagger-codegen generate -i %s -l %s -o %s -DpackageName=%s' % (SWAGGER_YAML_PATH, lang, outputDir, pkg))
