@@ -92,9 +92,9 @@ APIDOC_TYPE = {
 }
 
 OPENAPIDOC_TYPE = {
-    'int64': 'number',
-    'int32': 'number',
-    'int': 'number',
+    'int64': 'integer',
+    'int32': 'integer',
+    'int': 'integer',
     'float': 'number',
     'float32': 'number',
     'float64': 'number',
