@@ -5,6 +5,7 @@ from __future__ import print_function
 import os
 import sys
 import json
+import platform
 
 def IS_PY3():
     return sys.version_info >= (3, 0)
@@ -90,3 +91,6 @@ def update_m2c(new_version, cli_version='v2'):
         open('.m2c', 'wb').write(json.dumps(d, indent=2).encode('utf-8'))
     else:
         open('.m2c', 'wb').write(json.dumps(d, indent=2))
+
+def is_macos():
+    return platform.system() == 'Darwin'
