@@ -43,3 +43,10 @@ class SwaggerSchema(object):
             d['properties'] = dp
 
         return d
+
+    def clone(self):
+        c = SwaggerSchema(self.name, self.type, self.ref, self.description)
+        c.required = list(self.required)
+        c.properties = dict(self.properties)
+        c.items = self.items
+        return c
