@@ -38,11 +38,13 @@ vlogs = {
     '0.3.5': 'fix swagger tags/servers',
     '0.3.6': 'add service code template',
     '0.3.7': 'add cmdmodel',
-    '0.3.8': 'add wildcard router'
+    '0.3.8': 'add wildcard router',
+    '0.3.9': 'add swagger codegen',
+    '0.4.0': 'add swagger security, json resp model'
 }
 
 name = 'm2c'
-version = '0.3.8'
+version = '0.4.0'
 
 from .conf import M2C_PATH, Color
 from .helper import m2c_version
